{
  stdenv,
  fetchurl,
  lib,
  pkg-config,
  libaio,
  udev,
}:

stdenv.mkDerivation rec {
  pname = "lvm2";
  version = "2.03.30";

  src = fetchurl {
    urls = [
      "https://mirrors.kernel.org/sourceware/lvm2/LVM2.${version}.tgz"
      "ftp://sourceware.org/pub/lvm2/LVM2.${version}.tgz"
    ];
    hash = "sha256-rXar7LjciHcz4GxEnLmt0Eo1BvnweAwSiBem4aF87AU=";
  };

  nativeBuildInputs = [
    pkg-config
  ];
  buildInputs = [
      libaio
      udev
  ];

  configureFlags = [
    "--prefix=/"
    "--sbindir=/usr/bin"
    "--sysconfdir=/etc"
    "--localstatedir=/var"
    "--enable-cmdlib"
    "--enable-dmeventd"
    "--enable-lvmpolld"
    "--enable-pkgconfig"
    "--enable-udev_rules"
    "--enable-udev_sync"
    "--enable-write_install"
    "--with-cache=internal"
    "--with-thin=internal"
  ];

  preInstall = ''
    mkdir -p $out
    export DESTDIR=$out
  '';
  doCheck = false;

  meta = with lib; {
    homepage = "http://sourceware.org/lvm2/";
    description = "Tools to support Logical Volume Management (LVM) on Linux";
    platforms = platforms.linux;
    license = with licenses; [
      gpl2Only
      bsd2
      lgpl21
    ];
    maintainers = with maintainers; [
      raskin
      ajs124
    ];
  };
}
